@@ -13,7 +13,12 @@ ALG_NAMES <- c(NALG, DALG, OALG)
 #' Transpose since input for NMF::nmf uses rows as vars, cols as samples
 #' @noRd
 nmf <- function(x, k, method, seed) {
-  NMF::predict(NMF::nmf(t(x), rank = k, method = method, seed = seed))
+  if (!requireNamespace("NMF", quietly = TRUE)) {
+    stop("Package \"NMF\" is needed. Please install it.",
+         call. = FALSE)
+  } else {
+    NMF::predict(NMF::nmf(t(x), rank = k, method = method, seed = seed))
+  }
 }
 
 #' Transform to non-negative matrix by column-binding a negative replicate and
@@ -73,11 +78,15 @@ ap <- function(x, k) {
     stop("Package \"apcluster\" is needed. Please install it.",
          call. = FALSE)
   } else {
-    suppressWarnings(
-      apcluster::apclusterK(apcluster::negDistMat, x, k, verbose = FALSE)@idx
-    ) %>%
-      dplyr::dense_rank() %>%
-      purrr::when(length(.) > 0 ~ ., ~ NA)
+    ranks <-
+      apcluster::apclusterK(apcluster::negDistMat, x, k, verbose = FALSE)@idx %>%
+      suppressWarnings() %>%
+      dplyr::dense_rank()
+    if (length(ranks) > 0)  {
+      ranks
+    } else {
+      NA
+    }
   }
 }
 
@@ -105,14 +114,18 @@ block <- function(x, k) {
     stop("Package \"blockcluster\" is needed. Please install it.",
          call. = FALSE)
   } else {
-    tryCatch(
+    cl <- tryCatch(
       sink_output(
         blockcluster::cocluster(as.matrix(x), "continuous",
                                 nbcocluster = c(k, k))@rowclass + 1
       ),
       error = function(e) return(NA)
-    ) %>%
-      purrr::when(length(.) > 0 ~ ., ~ NA)
+    )
+    if (length(cl) > 0) {
+      cl
+    } else {
+      NA
+    }
   }
 }
 
@@ -123,8 +136,10 @@ som <- function(x, k, xdim, ydim, rlen, alpha, method) {
     stop("Package \"kohonen\" is needed. Please install it.",
          call. = FALSE)
   } else {
+    if (!is.matrix(x)) {
+      x <- as.matrix(x)
+    }
     x %>%
-      purrr::when(is.matrix(.) ~ ., ~ as.matrix(.)) %>%
       som_train(xdim = xdim, ydim = ydim, rlen = rlen, alpha = alpha) %>%
       som_cluster(k = k, method = method)
   }
