@@ -91,13 +91,13 @@ consensus_evaluate <- function(data, ..., cons.cl = NULL, ref.cl = NULL,
   ii <- cl.mat %>% purrr::map(ivi_table, data = data)
 
   # External indices if reference is given
-  ei <- ref.cl %>%
-    purrr::when(
-      !is.null(.) ~ cl.mat %>%
-        magrittr::extract(match(k, names(.))) %>% # for chosen k only
-        purrr::map(evi_table, ref.cl = ref.cl),
-      TRUE ~ NULL
-    )
+  if (!is.null(ref.cl)) {
+    ei <- cl.mat %>%
+      magrittr::extract(match(k, names(.))) %>% # for chosen k only
+      purrr::map(evi_table, ref.cl = ref.cl)
+  } else {
+    ei <- NULL
+  }
 
   # Only trim if more than one algorithm and trim is specified
   if (dim(E)[3] > 1 & trim) {
@@ -144,8 +144,11 @@ consensus_trim <- function(E, ii, k, k.method, reweigh, n) {
   top.list <- rank.obj$top.list
 
   # Algorithms to keep and remove based on top-ranked list
-  alg.keep <- top.list %>% purrr::when(is.null(.) ~ alg.all,
-                                       TRUE ~ .[seq_len(n)])
+  if (is.null(top.list)) {
+    alg.keep <- alg.all
+  } else {
+    alg.keep <- top.list[seq_len(n)]
+  }
   alg.remove <- as.character(alg.all[!(alg.all %in% alg.keep)])
   E.new <- E[, , alg.keep, k, drop = FALSE]
 
@@ -157,8 +160,9 @@ consensus_trim <- function(E, ii, k, k.method, reweigh, n) {
   # If k.method is to select "all", need to add suffixes to algorithms
   if (!is.null(k.method) && k.method == "all") {
     alg.keep <- paste_k(alg.keep, k)
-    alg.remove <- alg.remove %>%
-      purrr::when(length(.) > 0 ~ paste_k(., k), TRUE ~ .)
+    if (length(alg.remove) > 0) {
+      alg.remove <- paste_k(alg.remove, k)
+    }
     dimnames(E.new)[[3]] <- paste_k(dimnames(E.new)[[3]], k)
   }
   dplyr::lst(alg.keep, alg.remove, rank.matrix, top.list, E.new)
@@ -167,32 +171,21 @@ consensus_trim <- function(E, ii, k, k.method, reweigh, n) {
 #' Rank based on internal validity indices
 #' @noRd
 consensus_rank <- function(ii, n) {
-  # Extract internal indices and remove NaN idx
+  # Extract internal indices from clusterCrit and remove NaN idx
   ii.cc <- ii %>%
-    magrittr::extract(!names(.) %in% c("Algorithms") &
-                        purrr::map_lgl(., ~ all(!is.nan(.x))))
+    magrittr::extract(
+      !names(.) %in% c("Algorithms", "Compactness", "Connectivity") &
+        purrr::map_lgl(., ~ all(!is.nan(.x)))
+    )
 
   # Which algorithm is the best for each index?
-  bests <- purrr::imap_int(ii.cc, ~ {
-    switch(
-      .y,
-      calinski_harabasz = which.max(.x),
-      dunn = which.max(.x),
-      gamma = which.max(.x),
-      c_index = which.min(.x),
-      davies_bouldin = which.min(.x),
-      sd = which.min(.x),
-      s_dbw = which.min(.x),
-      silhouette = which.max(.x),
-      Compactness = which.min(.x),
-      Connectivity = which.min(.x)
-    )
-  })
+  bests <- purrr::imap_int(ii.cc, clusterCrit::bestCriterion)
   max.bests <- ii.cc %>%
     magrittr::extract(purrr::map_int(., which.max) == bests) %>%
     magrittr::multiply_by(-1)
   min.bests <- ii.cc %>%
-    magrittr::extract(purrr::map_int(., which.min) == bests)
+    magrittr::extract(purrr::map_int(., which.min) == bests) %>%
+    cbind(ii[c("Compactness", "Connectivity")]) # these two need to be minimized
 
   # Determine trimmed ensemble using rank aggregation
   if (nrow(ii) <= n) {
@@ -248,14 +241,12 @@ ivi_table <- function(cl.df, data) {
   ndata <- apply(data, 2, function(x) as.numeric(as.character(x)))
   data.frame(
     Algorithms = colnames(cl.df),
-    calinski_harabasz = cl.df %>% purrr::map_dbl(clusterSim::index.G1, x = ndata),
-    dunn = cl.df %>% purrr::map_dbl(clValid::dunn, distance = stats::dist(ndata)),
-    gamma = cl.df %>% purrr::map_dbl(clusterSim::index.G2, d = stats::dist(ndata)),
-    c_index = cl.df %>% purrr::map_dbl(clusterSim::index.C, d = stats::dist(ndata)),
-    davies_bouldin = cl.df %>% purrr::map_dbl(~ clusterSim::index.DB(x = ndata, cl = ., q = 1)[["DB"]]),
-    sd = cl.df %>% purrr::map_dbl(SD, data = ndata),
-    s_dbw = cl.df %>% purrr::map_dbl(S_Dbw, data = ndata),
-    silhouette = cl.df %>% purrr::map_dbl(clusterSim::index.S, d = stats::dist(ndata)),
+    cl.df %>% purrr::map_df(
+      clusterCrit::intCriteria,
+      traj = ndata,
+      crit = c("Calinski_Harabasz", "Dunn", "PBM", "Tau", "Gamma", "C_index",
+               "Davies_Bouldin", "McClain_Rao", "SD_Dis", "Ray_Turi", "G_plus",
+               "Silhouette", "S_Dbw")),
     Compactness = cl.df %>% purrr::map_dbl(compactness, data = data),
     Connectivity = cl.df %>% purrr::map_dbl(
       ~ suppressWarnings(clValid::connectivity(Data = ndata, clusters = .)))
@@ -270,16 +261,17 @@ ivi_table <- function(cl.df, data) {
 evi_table <- function(cl.df, ref.cl) {
   data.frame(
     Algorithms = colnames(cl.df),
-    hubert = cl.df %>% purrr::map_dbl(ev_hubert, cl2 = ref.cl),
-    jaccard = cl.df %>% purrr::map_dbl(ev_jaccard, cl2 = ref.cl),
-    mcnemar = cl.df %>% purrr::map_dbl(ev_mcnemar, cl2 = ref.cl),
-    rand = cl.df %>% purrr::map_dbl(ev_rand, cl2 = ref.cl),
+    cl.df %>% purrr::map_df(
+      clusterCrit::extCriteria,
+      part2 = ref.cl,
+      crit = c("Hubert", "Jaccard", "McNemar", "Rand")
+    ),
     NMI = cl.df %>% purrr::map_dbl(ev_nmi, ref.lab = ref.cl)
   ) %>%
     dplyr::inner_join(
       cl.df %>%
         purrr::map_dfr(ev_confmat, ref.lab = ref.cl, .id = "Algorithms") %>%
-        dplyr::select(-.data$.estimator) %>%
+        dplyr::select(-".estimator") %>%
         tidyr::pivot_wider(names_from = ".metric", values_from = ".estimate"),
       by = "Algorithms"
     ) %>%
