@@ -13,8 +13,8 @@ test_that("graph_cdf object can have added/modified ggplot layers", {
     stat_ecdf(aes(colour = Method)) +
     scale_color_brewer(palette = "Set2") +
     theme(legend.position = "none")
-  expect_is(p1, "ggplot")
-  expect_is(p2, "ggplot")
+  expect_s3_class(p1, "ggplot")
+  expect_s3_class(p2, "ggplot")
   expect_false(isTRUE(all.equal(p1, p2)))
 })
 
@@ -45,9 +45,18 @@ test_that("algii_heatmap works when there is more than one k", {
                  iris[1:25, 1:4])
   assign("gowerd", function(x) cluster::daisy(x, metric = "gower"), pos = 1)
   expect_error(
-    dice(iris2, nk = 3:4, reps = 2, algorithms = c("km", "pam"),
-         distance = "gowerd", k.method = "all", cons.funs = "majority",
-         plot = TRUE, progress = FALSE),
+    dice(
+      iris2,
+      nk = 3:4,
+      reps = 2,
+      algorithms = c("km", "pam"),
+      distance = "gowerd",
+      k.method = "all",
+      cons.funs = "majority",
+      plot = TRUE,
+      progress = FALSE,
+      verbose = FALSE
+    ),
     NA)
 })
 
