@@ -4,7 +4,7 @@ test_that("relabelling outputs a integer", {
   set.seed(2)
   pred <- sample(cl, 100, replace = TRUE)
   true <- sample(cl, 100, replace = TRUE)
-  expect_is(relabel_class(pred, true), "integer")
+  expect_type(relabel_class(pred, true), "integer")
 })
 
 test_that("flatten uses first clustering as reference if not relabelled", {
